Disclaimer
==========

See the `DISCLAIMER.md <disclaimer>`_ file for disclaimer information.

.. _disclaimer: https://code.usgs.gov/water/computational-tools/surface-water-work/hyswap/-/blob/main/DISCLAIMER.md


License
=======

See the `LICENSE.md <license>`_ file for license information.

.. _license: https://code.usgs.gov/water/computational-tools/surface-water-work/hyswap/-/blob/main/LICENSE.md
